Summary: The Linux kernel (the core of the Linux operating system).
Name: kernel
%define kversion 2.2.14
Version: %{kversion}
Release: 20000612
%define KVERREL %{PACKAGE_VERSION}-%{PACKAGE_RELEASE}
Copyright: GPL
Group: System Environment/Kernel
ExclusiveArch: armv4l
ExclusiveOS: Linux
Requires: modutils >= 2.3.6-1_nw1

Source0: linux-%{KVERREL}.tar.gz
Patch0: pcsound.patch
Patch1: freeswan-1.3.patch
Patch2: ip_masq_vpn-2.2.14.patch

BuildRoot: /var/tmp/kernel-%{KVERREL}-root
Provides: module-info
Autoreqprov: no

%package source
Requires: kernel-headers = %{kversion}
Summary: The source code for the Linux kernel.
Group: Development/System

%package headers
Summary: Header files for the Linux kernel.
Group: Development/System

%description
The kernel package contains the Linux kernel (vmlinux), the core of your
Red Hat Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

%description source
The kernel-source package contains the source code files for the Linux
kernel. These source files are needed to build most C programs, since
they depend on the constants defined in the source code. The source
files can also be used to build a custom kernel that is better tuned to
your particular hardware, if you are so inclined (and you know what you're
doing).

%description headers
Kernel-headers includes the C header files for the Linux kernel.  The
header files define structures and constants that are needed for building
most standard programs.  The header files are also needed for rebuilding
the kernel.

###
### prep
###
%prep
%setup -q -n linux
%patch0 -p1
%patch1 -p1
%patch2 -p1

###
### build
###
%build

cp arch/arm/def-configs/netwinder arch/arm/defconfig
# make sure EXTRAVERSION says what we want it to say
sed -e 's/^EXTRAVERSION.*/EXTRAVERSION = -%{release}/' Makefile >Makefile.new
mv Makefile.new Makefile
rm -f .config
make mrproper
make oldconfig
make dep 
make Image
make modules 

###
### install
###
%install

mkdir -p $RPM_BUILD_ROOT/boot
install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-%{KVERREL}
cp arch/arm/boot/Image $RPM_BUILD_ROOT/boot/vmlinux-%{KVERREL}
mkdir -p $RPM_BUILD_ROOT/lib/modules/%{KVERREL}/{block,cdrom,fs,ipv4,misc,net,scsi,video}
make INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=%{KVERREL}

# Kludge: if "old_tulip" was created, rename it to "tulip". 
# This should be fixed in 2.2.15 and then we can take this out.
tulipdir=$RPM_BUILD_ROOT/lib/modules/%{KVERREL}/net
if [ -e $tulipdir/old_tulip.o ]; then
	mv $tulipdir/old_tulip.o $tulipdir/tulip.o
fi

mkdir -p $RPM_BUILD_ROOT/usr/include
ln -sf ../src/linux/include/linux $RPM_BUILD_ROOT/usr/include/linux
ln -sf ../src/linux/include/asm $RPM_BUILD_ROOT/usr/include/asm

mkdir -p $RPM_BUILD_ROOT/usr/src/linux-%{kversion} 
tar cf - . | tar xf - -C $RPM_BUILD_ROOT/usr/src/linux-%{kversion}
ln -sf linux-%{kversion} $RPM_BUILD_ROOT/usr/src/linux

# clean up destination
make mrproper -C $RPM_BUILD_ROOT/usr/src/linux-%{kversion}
make oldconfig -C $RPM_BUILD_ROOT/usr/src/linux-%{kversion}
make symlinks -C $RPM_BUILD_ROOT/usr/src/linux-%{kversion}
make include/linux/version.h -C $RPM_BUILD_ROOT/usr/src/linux-%{kversion}

###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

%post
cd /boot
ln -sf vmlinux-%{KVERREL} vmlinux
ln -sf System.map-%{KVERREL} System.map

%preun
if [ -e /lib/modules/%{KVERREL}/modules.dep ]; then
  rm /lib/modules/%{KVERREL}/modules.dep
fi
exit 0

%post headers
cd /usr/src
rm -f linux
ln -snf linux-%{kversion} linux

%post source
cd /usr/src
rm -f linux
ln -snf linux-%{kversion} linux

%postun headers
if [ -L /usr/src/linux ]; then 
    if [ `ls -l /usr/src/linux | awk '{ print $11 }'` = "linux-%{kversion}" ]; then
	[ $1 = 0 ] && rm -f /usr/src/linux
    fi
fi
exit 0

%postun source
if [ -L /usr/src/linux ]; then 
    if [ `ls -l /usr/src/linux | awk '{ print $11 }'` = "linux-%{kversion}" ]; then
	[ $1 = 0 ] && rm -f /usr/src/linux
    fi
fi
exit 0

###
### file lists
###

%files
%defattr(-,root,root,-)
/boot/vmlinux-%{KVERREL}
/boot/System.map-%{KVERREL}
%dir /lib/modules
/lib/modules/%{KVERREL}

# Source package contains all but the "include" directory
%files source
%defattr(-,root,root,-)
/usr/src/linux-%{kversion}/COPYING
/usr/src/linux-%{kversion}/CREDITS
/usr/src/linux-%{kversion}/Documentation
/usr/src/linux-%{kversion}/MAINTAINERS
/usr/src/linux-%{kversion}/Makefile
/usr/src/linux-%{kversion}/README
/usr/src/linux-%{kversion}/REPORTING-BUGS
/usr/src/linux-%{kversion}/Rules.make
/usr/src/linux-%{kversion}/arch
/usr/src/linux-%{kversion}/drivers
/usr/src/linux-%{kversion}/fs
/usr/src/linux-%{kversion}/init
/usr/src/linux-%{kversion}/ipc
/usr/src/linux-%{kversion}/kernel
/usr/src/linux-%{kversion}/lib
/usr/src/linux-%{kversion}/mm
/usr/src/linux-%{kversion}/modules
/usr/src/linux-%{kversion}/net
/usr/src/linux-%{kversion}/scripts

%files headers
%defattr(-,root,root,-)
%dir /usr/src/linux-%{kversion}
%ifarch armv4l
/usr/src/linux-%{kversion}/include/asm-arm
%endif
/usr/src/linux-%{kversion}/include/asm
/usr/src/linux-%{kversion}/include/asm-generic
/usr/src/linux-%{kversion}/include/linux
/usr/src/linux-%{kversion}/include/net
/usr/src/linux-%{kversion}/include/scsi
/usr/src/linux-%{kversion}/include/video
/usr/include/asm
/usr/include/linux

%changelog
* Fri Jun 9 2000 Ralph Siemsen <ralphs@netwinder.org>
- Fixed setuid() capability security problem
- Added nwled driver
- msr [cs]psr_c, #imm code fixed for new binutils
- cyberpro h/v_sync initialized to nonzero, for initrd
- initialize AC bit in the nwfpe

* Tue Apr 11 2000 Ralph Siemsen <ralphs@netwinder.org>
- This package can now be built as non-root
- Added freeswan, VPN masq, and pcspeaker support as patches
- Kludge around the tulip driver being renamed

* Tue Mar 28 2000 Ralph Siemsen <ralphs@netwinder.org>
- Added requirement for new modutils package

* Sun Dec 12 1999 Ralph Siemsen <ralphs@netwinder.org>
- Add pre-uninstall script to remove modules.dep if it exists

* Thu Nov 18 1999 Ralph Siemsen <ralphs@netwinder.org>
- Update to 2.2.12 (cvs tagged nw-2_2_9-4)
- Fix tulip cache flush problems
- Fix tcp_checksum problem (psr corruption on fault hander exit)

* Mon Jun 7 1999 Ralph Siemsen <ralphs@netwinder.org>
- Update to 2.2.9-rmk1 kernel (cvs tagged nw-2_2_9-1)

* Tue May 18 1999 Ralph Siemsen <ralphs@netwinder.org>
- initial version for NetWinder
